@charset "utf-8";

/*! bulma.io v1.0.3 | MIT License | github.com/jgthms/bulma */
@forward "../sass/utilities";
@forward "../sass/base";
@forward "../sass/elements";
@forward "../sass/form";
@forward "../sass/components";
@forward "../sass/grid";
@forward "../sass/layout";
@forward "../sass/base/skeleton";
@forward "../sass/helpers";

@use "../sass/themes/light";
@use "../sass/themes/setup";

:root {
  @include light.light-theme;
  @include setup.setup-theme;
}
