# Generated by Django 5.1.7 on 2025-03-16 18:11

import accrete.contrib.user.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('user', '0002_user_theme'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='email',
            field=models.EmailField(max_length=254, unique=True, validators=[accrete.contrib.user.models.validate_member_login], verbose_name='Email Address'),
        ),
    ]
