.has-icon {
  padding-left: 8px;
  padding-right: 8px;
  min-width: 40px;
  background-color: transparent;
}

.icon-open-related {
  background-image:url('data:image/svg+xml;charset=utf-8,%3Csvg viewBox=%22177 17 86 86%22 version=%221.2%22 xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath d=%22M240 20h20m0 0v20m0-20-40 40m40 0v20m0 0s0 20-20 20m0 0h-40m0 0s-20 0-20-20m0 0V40m0 0s0-20 20-20m20 0h-20%22 fill=%22none%22 stroke-width=%225%22 stroke-linecap=%22round%22 stroke-linejoin=%22round%22 stroke=%22%23283330%22 stroke-miterlimit=%2210%22/%3E%3C/svg%3E');
  height: 20px;
  width: 20px;
  background-size: 100%;
  background-position: center;
  background-repeat: no-repeat;
}

.icon-envelope {
  background-image:url('data:image/svg+xml;charset=utf-8,%3Csvg width=%22240%22 height=%22120%22 viewBox=%2297 97 166 86%22 version=%221.2%22 xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath style=%22fill:none;stroke-width:5;stroke-linecap:round;stroke-linejoin:round;stroke:%23283330;stroke-opacity:1;stroke-miterlimit:10%22 d=%22M100 180h160v-80H100v80%22/%3E%3Cpath style=%22fill:none;stroke-width:5;stroke-linecap:round;stroke-linejoin:round;stroke:%23283330;stroke-opacity:1;stroke-miterlimit:10%22 d=%22m100 100 80 40 80-40%22/%3E%3C/svg%3E');
  height: 20px;
  width: 20px;
  background-size: 100%;
  background-position: center;
  background-repeat: no-repeat;
}

.icon-clear {
  background-image:url("data:image/svg+xml;charset=utf-8,%3Csvg width=%22360%22 height=%22360%22 viewBox=%2297 97 166 86%22 version=%221.2%22 xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath style=%22fill:none;stroke-width:5;stroke-linecap:round;stroke-linejoin:round;stroke:%23283330;stroke-opacity:1;stroke-miterlimit:10%22 d=%22M260 100v80h-80l-80-40 80-40h80m-80 0 80 80m-80 0 80-80%22/%3E%3C/svg%3E");
  height: 20px;
  width: 20px;
  background-size: 100%;
  background-position: center;
  background-repeat: no-repeat;
}

.icon-backspace {
  background-image:url("data:image/svg+xml;charset=utf-8,%3Csvg width=%22360%22 height=%22360%22 viewBox=%2255 94 211 132%22 version=%221.2%22 xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath style=%22fill:none;stroke-width:10;stroke-linecap:round;stroke-linejoin:round;stroke:%23283330;stroke-opacity:1;stroke-miterlimit:10%22 d=%22M260 100v120H140m120-120H140m-80 60 80-60m-80 60 80 60m20-80 60 40m-60 0 60-40%22/%3E%3C/svg%3E");
  height: 20px;
  width: 20px;
  background-size: 100%;
  background-position: center;
  background-repeat: no-repeat;
}

.icon-filter {
  background-image:url("data:image/svg+xml;charset=utf-8,%3Csvg width=%2248%22 height=%2248%22 xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath style=%22stroke-linecap:round;stroke-width:1;stroke:%23000;fill:none%22 d=%22M45 5 30 20v17l-9.95 9.35V25.78L20 20 4.99 4.82Z%22/%3E%3C/svg%3E");
  height: 20px;
  width: 20px;
  background-size: 100%;
  background-position: center;
  background-repeat: no-repeat;
}

.icon-delete-filter {
  background-image:url("data:image/svg+xml;charset=utf-8,%3Csvg xmlns=%22http://www.w3.org/2000/svg%22 width=%22360%22 height=%22360%22 version=%221.2%22%3E%3Cpath style=%22fill:none;stroke-width:10;stroke-linecap:round;stroke-linejoin:round;stroke:%23283330;stroke-opacity:1;stroke-miterlimit:10%22 d=%22M20 340 340 20M40 60h240m40 0h20M140 340V240m0 100 80-80m0 0V160m0 0L340 60M140 200v-40M40 60H20m120 100L20 60%22/%3E%3C/svg%3E");
  height: 20px;
  width: 20px;
  background-size: 100%;
  background-position: center;
  background-repeat: no-repeat;
}

.icon-edit {
  background-image:url("data:image/svg+xml;charset=utf-8,%3Csvg width=%22360%22 height=%22360%22 version=%221.2%22 xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath style=%22fill:none;stroke:%23283330;stroke-width:19.5459;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:10;stroke-opacity:1%22 d=%22m52.494 317.303 42.557-97.274m-42.557 97.274 85.113-48.636m0 0-42.556-48.638m42.556 48.636L307.832 74.121m-212.78 145.91L265.276 25.485m0 0 42.557 48.636m-85.113 0 42.556 48.636%22 transform=%22translate(-.164 8.606)%22/%3E%3C/svg%3E");
  height: 20px;
  width: 20px;
  background-size: 100%;
  background-position: center;
  background-repeat: no-repeat;
}

.icon-select {
  background-image:url("data:image/svg+xml;charset=utf-8,%3Csvg width=%22360%22 height=%22360%22 version=%221.2%22 xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath style=%22fill:none;stroke-width:20;stroke-linecap:round;stroke-linejoin:round;stroke:%23283330;stroke-opacity:1;stroke-miterlimit:10%22 d=%22M60 20s-40 0-40 40m280-40s40 0 40 40M20 300s0 40 40 40M20 100v160m80-240h160m-40 320-40-160m160 40-160-40m40 160 40-80m0 0 80-40M180 340h-80m240-160v-80%22/%3E%3C/svg%3E");
  height: 20px;
  width: 20px;
  background-size: 100%;
  background-position: center;
  background-repeat: no-repeat;
}

.icon-add {
  background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg width=%22360%22 height=%22360%22 version=%221.2%22 xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cg style=%22stroke:%23000;stroke-opacity:1%22%3E%3Cpath style=%22fill:none;stroke-width:40;stroke-linecap:round;stroke-linejoin:round;stroke:%23000;stroke-opacity:1;stroke-miterlimit:10%22 d=%22M180 20v320M20 180h320%22/%3E%3C/g%3E%3C/svg%3E");
  height: 20px;
  width: 20px;
  background-size: 100%;
  background-position: center;
  background-repeat: no-repeat;
}

.icon-list {
  background-image: url("data:image/svg+xml;charset=utf-8,%3Csvg width=%22360%22 height=%22360%22 xmlns=%22http://www.w3.org/2000/svg%22%3E%3Cpath style=%22fill:%23000;stroke:%23000;stroke-width:1.27605;stroke-linecap:round;stroke-linejoin:bevel%22 d=%22M17.328 30.677h323.725s17.307.113 17.307 14.852c.197 14.986-16.095 13.81-16.095 13.81H18.483S1 58.3 1.656 44.97c-.13-15.795 15.672-14.292 15.672-14.292Zm-1 90h323.725s17.307.113 17.307 14.852c.197 14.986-16.095 13.81-16.095 13.81H17.483S-.002 148.3.656 134.97c-.13-15.795 15.672-14.292 15.672-14.292Zm0 90h323.725s17.307.113 17.307 14.852c.197 14.986-16.095 13.81-16.095 13.81H17.483S-.002 238.3.656 224.97c-.13-15.795 15.672-14.292 15.672-14.292Zm0 90h323.725s17.307.113 17.307 14.852c.197 14.986-16.095 13.81-16.095 13.81H17.483S-.002 328.3.656 314.97c-.13-15.795 15.672-14.292 15.672-14.292Z%22/%3E%3C/svg%3E");
  height: 20px;
  width: 20px;
  background-size: 100%;
  background-position: center;
  background-repeat: no-repeat;
}
