# Generated by Django 5.1.7 on 2025-03-31 20:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accrete', '0006_alter_member_user'),
    ]

    operations = [
        migrations.AddField(
            model_name='accessgroup',
            name='description',
            field=models.TextField(blank=True, null=True, verbose_name='Description'),
        ),
    ]
