{% if is_new %}
    <div hx-swap-oob="beforeend:#list-grid">
        {% include 'ui/list.html#entry' %}
    </div>
{% else %}
    <div hx-swap-oob="innerHTML:#list-data-{{ instance.pk }}">
        {% include list_entry_template with instance=instance %}
    </div>
{% endif %}