{% load i18n %}

{% if form.non_field_errors or form.save_error %}
    <div class="notification is-danger is-light" style="word-wrap: break-word;">
        {{ form.non_field_errors }}
        {% if form.save_error %}
            <p>{{ form.save_error }}</p>
            {% if form.save_error_id %}<span>{% translate 'Error ID' %}: {{ form.save_error_id }}</span>{% endif %}
        {% endif %}
    </div>
{% endif %}
