# Generated by Django 5.1.1 on 2025-01-10 07:57

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('accrete', '0002_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='member',
            name='name',
        ),
    ]
