{% load static %}
{% load i18n %}

<div class="file has-name is-fullwidth">
    <label class="file-label">
        <input class="file-input"
               type="file"
               name="{{ widget.name }}"
                {% if widget.value != None %} value="{{ widget.value|stringformat:'s' }}"{% endif %}
                {% include "django/forms/widgets/attrs.html" %}
        >
        <span class="file-cta">
            <span class="file-icon">
                <i class="fas fa-upload"></i>
            </span>
            <span class="file-label">
                {% translate 'Choose a file' %}
            </span>
        </span>
        <span class="file-name">
            {% translate 'No file selected' %}
        </span>
    </label>
</div>